Module cache

Module cache 

Structs

CacheStats
Summary information for the persistent build cache.

Functions

clear
Clear every persistent build cache entry.
clear_lang
Clear entries belonging to a single language namespace.
lookup
Look up a cached binary path for a language namespace and source hash.
root_dir
Return the root directory for run-kit cache data.
stats
Return cache statistics from the current index.
store
Store a compiled binary for a language namespace and source hash.
workspace
Return an incremental workspace path managed by the build cache.