pub fn run_cli()Expand description
Main CLI logic that can be called from external wrappers.
This function is public to allow the runtool wrapper crate to reuse the same logic.
pub fn run_cli()Main CLI logic that can be called from external wrappers.
This function is public to allow the runtool wrapper crate to reuse the same logic.