Module executor

Module executor 

Script execution and error formatting.

Functions

execute_file
Execute a script file by path.
execute_script
Parse and execute a script file.
list_functions
List all available functions from the Runfile.
print_parse_error
Print a parse error with context from the source code.
run_function_call
Load function definitions from config and call a function with arguments.