CLI module containing the main entry point logic.
This module is separated from main.rs to allow the runtool wrapper crate to reuse it.
Enums
- Output
Format Arg - Output format for command execution
Functions
- run_cli
- Main CLI logic that can be called from external wrappers.