Script execution and error formatting.
Functions
- execute_
file - Execute a script file by path.
- execute_
script - Parse and execute a script file.
- list_
functions - List all available functions from the Runfile.
- print_
parse_ error - Print a parse error with context from the source code.
- run_
function_ call - Load function definitions from config and call a function with arguments.