Interpreter to execute the AST
This module provides the main interpreter for executing parsed Run scripts. It handles function definitions, variable substitution, and command execution with support for multiple interpreters (sh, bash, python, node, ruby, etc.)